@@ -1,9 +1,3 @@
 (function() {var implementors = {};
 implementors["std"] = [{"text":"impl <a class=\"trait\" href=\"std/hash/trait.BuildHasher.html\" title=\"trait std::hash::BuildHasher\">BuildHasher</a> for <a class=\"struct\" href=\"std/collections/hash_map/struct.RandomState.html\" title=\"struct std::collections::hash_map::RandomState\">RandomState</a>","synthetic":false,"types":["std::collections::hash::map::RandomState"]}];
-
-            if (window.register_implementors) {
-                window.register_implementors(implementors);
-            } else {
-                window.pending_implementors = implementors;
-            }
-        })()
\ No newline at end of file
+if (window.register_implementors) {window.register_implementors(implementors);} else {window.pending_implementors = implementors;}})()
\ No newline at end of file
